@@ -270,7 +270,6 @@ sub visitBooleanLiteral {
 sub visitTypeDeclarator {
 	my $self = shift;
 	my ($node) = @_;
-	return if (exists $node->{modifier});	# native IDL2.2
 	$self->visitType($node->{type});
 	if (exists $node->{array_size}) {
 		foreach (@{$node->{array_size}}) {
@@ -279,6 +278,10 @@ sub visitTypeDeclarator {
 	}
 }
 
+sub visitNativeType {
+	# empty
+}
+
 #
 #	3.11.1	Basic Types
 #
